
giving.utils
============

.. automodule:: giving.utils

    .. autofunction:: keyword_decorator
    .. autofunction:: lax_function
    .. autofunction:: reducer(func=None, default_seed=NotSet, postprocess=NotSet)
    .. autofunction:: reduced_traceback
